    
          SpaceShower
          =========== 

The Pythia algorithm for spacelike initial-state showers is based on
the recent article [1], where a transverse-momentum-ordered
backwards evolution scheme is introduced. This algorithm is a
further development of the virtuality-ordered one presented in
[2], with matching to first-order matrix element for Z0, W+- and
Higgs (in the m_t -> infinity limit) production as introduced in [3]. 

The normal user is not expected to call SpaceShower directly, but only
have it called from Pythia, via PartonLevel. Some of the parameters 
below, in particular SpaceShower:alphaSvalue, would be of interest for 
a tuning exercise, however. 

---------------------------------------------------------------------- 

   Physics strategy
   ----------------

Almost everything is equivalent to the algorithm in [1]. Minor changes 
are as follows.

It is now possible to have a second-order running alpha_s,
in addition to fixed or first-order running. 

The description of heavy flavour production in the threshold region 
has been modified, so as to be more forgiving about mismatches 
between the c/b  masses used in Pythia relative to those used in a
respective PDF parametrization. The basic idea is that, in the
threshold region of a heavy quark Q, Q = c or b, the effect of
subsequent Q -> Q g branchings is negligible. If so, then
   f_Q(x, pT2) = integral_mQ2^pT2  dpT'2/pT'2 * alpha_s(pT'2)/2pi
      * integral P(z) g(x', pT'2) delta(x - z x')
so use this to select the pT2 of the g -> Q Qbar branching. In the
old formalism the same kind of behaviour should be obtained, but by
a cancellation of a 1/f_Q that diverges at the theshold and a
Sudakov that vanishes.

The strategy therefore is that, once pT2 < f * mQ2, with f a parameter
of the order of 2, a pT2 is chosen like dpT2/pT2 between mQ2 and
f * mQ2, and a z flat in the allowed range. Thereafter acceptance
is based on the product of three factors, representing the running
of alpha_strong, the splitting kernel (including the mass term) and
the gluon density weight. At failure, a new pT2 is chosen in the same 
range, i.e. is not required to be lower since no Sudakov is involved. 

---------------------------------------------------------------------- 

   Main variables
   --------------

There are three flags you can use to switch on or off selected
branchings in the shower: 

<flag> SpaceShower:QCDshower = on
Allow a QCD shower; on/off = true/false.

<flag> SpaceShower:QEDshowerByQ = on
Allow quarks to radiate photons; on/off = true/false.

<flag> SpaceShower:QEDshowerByL = on
Allow leptons to radiate photons; on/off = true/false.

The amount of QCD radiation in the shower is determined by 

<parameter> SpaceShower:alphaSvalue = 0.127 min = 0.06 max = 0.25
The alpha_strong value at scale M_Z^2. Default value is picked equal
to the one used in CTEQ 5L.  

The actual value is then regulated by the running to the scale pT^2,
at which it is evaluated

<mode> SpaceShower:alphaSorder = 1 min = 0 max = 2
Order at which alpha_strong runs,
0 = zeroth order, i.e. alpha_strong is kept fixed.
1 = first order, which is the normal value.
2 = second order. Since other parts of the code do not go to second 
    order there is no strong reason to use this option, but there is 
    also nothing wrong with it.

QED radiation is currently regulated by StandardModel:alphaEMfix,
since no QED running is implemented in the shower.

There are two complementary ways of regularizing the small-pT 
divergence, a sharp cutoff and a smooth dampening. These can be 
combined as desired but it makes sense to coordinate with how the 
same issue is handled in multiple interactions.

<flag> SpaceShower:samePTasMI = on
Regularize the pT -> 0 divergence using the same sharp cutoff and 
smooth dampening parameters as used to describe multiple interactions.
That is, the MultipleInteractions:pT0Ref, MultipleInteractions:ecmRef,
MultipleInteractions:ecmPow and MultipleInteractions:pTmin parameters 
are used to regularize all ISR QCD radiation, rather than the 
corresponding parameters below. This is a sensible physics ansatz,
based on the assumption that colour screening effects influence 
both MI and ISR in the same way. Photon radiation is regularized 
separately in either case.
Warning: if a large pT0 is picked for multiple interactions, 
such that the integrated interaction cross section is below the 
nondiffractive inelastic one, this pT0 will automatically be scaled
down to cope. Information on such a rescaling does NOT propagate to
SpaceShower, however.
  
<parameter> SpaceShower:pT0Ref = 2.5 min = 0.5 max = 10.0
Regularization of the divergence of the QCD emission probability for 
pT -> 0 is obtained by a factor pT^2 / (pT0^2 + pT^2), and by 
using an alpha_s(pT0^2 + pT^2). An energy dependence of the pT0 
choice is introduced by the next two parameters, so that pT0Ref 
is the pT0 value for the reference cm energy, pT0Ref = pT0(ecmRef).   

<parameter> SpaceShower:ecmRef = 1800.0 min = 1.
<parameter> SpaceShower:ecmPow = 0.16 min = 0. max = 0.5
The actual pT0 parameter used at a given cm energy scale, ecmNow,
is obtained as
     pT0 = pT0(ecmNow) = pT0Ref * (ecmNow / ecmRef)^ecmPow 
where pT0Ref, ecmRef and ecmPow are the three parameters above.

<parameter> SpaceShower:pTmin = 0.2 min = 0.1 max = 10.0
Lower cutoff in pT, below which no further ISR branchings 
are allowed. Normally pT0 above would be used to provide the main 
regularization of the branching rate for pT -> 0, in which case 
pTmin is used  mainly for technical reasons. It is possible,
however, to set pT0Ref = 0 and use pTmin to provide a step-function
regularization, or combine them in intermediate approaches.
Currently pTmin is taken to be energy-independent.  

<parameter> SpaceShower:pTminChgQ = 0.5 min = 0.01
Parton shower cut-off pT for photon coupling to coloured particle.

<parameter> SpaceShower:pTminChgL = 0.0005 min = 0.0001
Parton shower cut-off mass for pure QED branchings. 
Assumed smaller than (or equal to) pTminChgQ.
Actually, ISR cascades of incoming leptons have not been implemented 
so far, so should not be used!??

---------------------------------------------------------------------- 

   Further variables
   -----------------

<flag> SpaceShower:MEcorrections = on
Use of matrix element corrections; on/off = true/false.

<flag> SpaceShower:phiPolAsym = on
Azimuthal asymmetry induced by gluon polarization; on/off = true/false.
Not yet implemented. 

<mode> SpaceShower:nQuark = 5 min = 0 max = 5
Number of allowed quark flavours in g -> q qbar branchings.
Changing it to 4 would forbid g -> b bbar, etc.
   
---------------------------------------------------------------------- 

References
 
[1] T. Sjstrand and P.Z. Skands, Eur. Phys. J. C39 (2005) 129 

[2] T. Sjstrand, Phys. Lett. 157B (1985) 321;
    M. Bengtsson, T. Sjstrand and M. van Zijl, Z. Phys. C32 (1986) 67

[3] G. Miu and T. Sjstrand, Phys. Lett. B449 (1999) 313 

---------------------------------------------------------------------- 

Copyright  2005 Torbjrn Sjstrand


